| Title: | Data Frames with Persistent Columns and Attributes |
|---|---|
| Description: | Provides data frames that hold certain columns and attributes persistently for data processing in 'dplyr'. |
| Authors: | Mizuki Uchida [aut, cre] |
| Maintainer: | Mizuki Uchida <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.2 |
| Built: | 2026-05-14 08:37:33 UTC |
| Source: | https://github.com/uchidamizuki/stickyr |
'as_sticky_tibble' turns an object to a sticky tibble ('sticky_tbl_df').
as_sticky_tibble(x, ...)as_sticky_tibble(x, ...)
x |
An object. |
... |
Unused, for extensibility. |
A sticky tibble ('sticky_tbl_df') object.
Test if the object is a sticky tibble
is_sticky_tibble(x)is_sticky_tibble(x)
x |
An object |
TRUE if an object inherits from sticky_tbl_df,
sticky_grouped_df or sticky_rowwise_df class.
new_sticky_tibble constructs a tibble with persistent columns and
attributes. These persistent columns can be hidden.
new_sticky_tibble( x = list(), cols = NULL, col_show = tidyselect::everything(), col_summary = list(), attrs = character(), ..., class = character(), class_grouped_df = class, class_rowwise_df = class )new_sticky_tibble( x = list(), cols = NULL, col_show = tidyselect::everything(), col_summary = list(), attrs = character(), ..., class = character(), class_grouped_df = class, class_rowwise_df = class )
x |
A tibble-like object. |
cols |
Columns to be kept persistently. |
col_show |
Which persistent columns to show? By default, all are displayed. |
col_summary |
A named list of functions to summarise persistent columns. |
attrs |
Names of attributes to be kept persistently. |
... |
Additional attributes. |
class |
Subclasses. |
class_grouped_df |
Subclasses of grouped_df. By default, it is the same
as |
class_rowwise_df |
Subclasses of rowwise_df. By default, it is the same
as |
A sticky tibble (sticky_tbl_df) object.